@@ -19,14 +19,6 @@
 
 #include "reportassistantpages_bugzilla.h"
 
-#include "reportinterface.h"
-#include "systeminformation.h"
-#include "crashedapplication.h"
-#include "statuswidget.h"
-#include "drkonqi.h"
-#include "drkonqi_globals.h"
-#include "applicationdetailsexamples.h"
-
 #include <QtCore/QTimer>
 
 #include <QLabel>
@@ -42,7 +34,7 @@
 #include <KMessageBox>
 #include <KToolInvocation>
 #include <KWallet/Wallet>
-#include <kcapacitybar.h>
+#include <KCapacityBar>
 
 /* Unhandled error dialog includes */
 #include <KFileDialog>
@@ -51,6 +43,15 @@
 #include <KIO/NetAccess>
 #include <KTemporaryFile>
 
+#include "reportinterface.h"
+#include "systeminformation.h"
+#include "crashedapplication.h"
+#include "bugzillalib.h"
+#include "statuswidget.h"
+#include "drkonqi.h"
+#include "drkonqi_globals.h"
+#include "applicationdetailsexamples.h"
+
 static const char kWalletEntryName[] = "drkonqi_bugzilla";
 static const char kWalletEntryUsername[] = "username";
 static const char kWalletEntryPassword[] = "password";
@@ -69,7 +70,7 @@ BugzillaLoginPage::BugzillaLoginPage(ReportAssistantDialog * parent) :
     connect(bugzillaManager(), SIGNAL(loginError(QString,QString)), this, SLOT(loginError(QString,QString)));
 
     ui.setupUi(this);
-    ui.m_statusWidget->setIdle(i18nc("@info:status '1' is replaced with \"bugs.kde.org\"",
+    ui.m_statusWidget->setIdle(i18nc("@info:status '1' is replaced with the short URL of the bugzilla ",
                                    "You need to login with your %1 account in order to proceed.",
                                    QLatin1String(KDE_BUGZILLA_SHORT_URL)));
 
@@ -78,11 +79,16 @@ BugzillaLoginPage::BugzillaLoginPage(ReportAssistantDialog * parent) :
                                               i18nc("@info:tooltip", "Use this button to login "
                                               "to the KDE bug tracking system using the provided "
                                               "username and password.")));
+    ui.m_loginButton->setEnabled(false);
+
     connect(ui.m_loginButton, SIGNAL(clicked()) , this, SLOT(loginClicked()));
 
     connect(ui.m_userEdit, SIGNAL(returnPressed()) , this, SLOT(loginClicked()));
     connect(ui.m_passwordEdit, SIGNAL(returnPressed()) , this, SLOT(loginClicked()));
 
+    connect(ui.m_userEdit, SIGNAL(textChanged(QString)) , this, SLOT(updateLoginButtonStatus()));
+    connect(ui.m_passwordEdit, SIGNAL(textChanged(QString)) , this, SLOT(updateLoginButtonStatus()));
+
     ui.m_noticeLabel->setText(
                         i18nc("@info/rich","<note>You need a user account on the "
                             "<link url='%1'>KDE bug tracking system</link> in order to "
@@ -99,6 +105,12 @@ bool BugzillaLoginPage::isComplete()
     return bugzillaManager()->getLogged();
 }
 
+void BugzillaLoginPage::updateLoginButtonStatus()
+{
+    ui.m_loginButton->setEnabled( !ui.m_userEdit->text().isEmpty() &&
+                                  !ui.m_passwordEdit->text().isEmpty() );
+}
+
 void BugzillaLoginPage::loginError(const QString & err, const QString & extendedMessage)
 {
     loginFinished(false);
@@ -140,11 +152,11 @@ void BugzillaLoginPage::aboutToShow()
     }
 }
 
-bool BugzillaLoginPage::kWalletEntryExists()
+bool BugzillaLoginPage::kWalletEntryExists(const QString& entryName)
 {
     return !KWallet::Wallet::keyDoesNotExist(KWallet::Wallet::NetworkWallet(),
                                                KWallet::Wallet::FormDataFolder(),
-                                               QLatin1String(kWalletEntryName));
+                                               entryName);
 }
 
 void BugzillaLoginPage::openWallet()
@@ -159,7 +171,7 @@ void BugzillaLoginPage::openWallet()
 void BugzillaLoginPage::walletLogin()
 {
     if (!m_wallet) {
-        if (kWalletEntryExists()) {  //Key exists!
+        if (kWalletEntryExists(QLatin1String(kWalletEntryName))) {  //Key exists!
             openWallet();
             ui.m_savePasswordCheckBox->setCheckState(Qt::Checked);
             //Was the wallet opened?
@@ -177,9 +189,7 @@ void BugzillaLoginPage::walletLogin()
                     ui.m_passwordEdit->setText(password);
                 }
             }
-        } else if (!KWallet::Wallet::keyDoesNotExist(KWallet::Wallet::NetworkWallet(),
-                                               KWallet::Wallet::FormDataFolder(),
-                                               QLatin1String(konquerorKWalletEntryName))) {
+        } else if (kWalletEntryExists(QLatin1String(konquerorKWalletEntryName))) {
             //If the DrKonqi entry is empty, but a Konqueror entry exists, use and copy it.
             openWallet();
             if (m_wallet) {
@@ -248,7 +258,7 @@ bool BugzillaLoginPage::canSetCookies()
                               "Allow %1 to set cookies", KDE_BUGZILLA_URL));
 
         KGuiItem noItem = KStandardGuiItem::no();
-        noItem.setText(i18nc("@action:button do not allow bugs.kde.org "
+        noItem.setText(i18nc("@action:button do not allow the bugzilla website "
                              "to set cookies", "No, do not allow"));
 
         if (KMessageBox::warningYesNo(this, msg, QString(), yesItem, noItem) == KMessageBox::Yes) {
@@ -301,7 +311,7 @@ void BugzillaLoginPage::loginClicked()
             }
 
         } else { //User doesn't want to save or wants to remove.
-            if (kWalletEntryExists()) {
+            if (kWalletEntryExists(QLatin1String(kWalletEntryName))) {
                 if (!m_wallet) {
                     openWallet();
                 }
@@ -317,8 +327,7 @@ void BugzillaLoginPage::loginClicked()
                                       "Performing login at %1 as %2...",
                                       QLatin1String(KDE_BUGZILLA_SHORT_URL), ui.m_userEdit->text()));
 
-        bugzillaManager()->setLoginData(ui.m_userEdit->text(), ui.m_passwordEdit->text());
-        bugzillaManager()->tryLogin();
+        bugzillaManager()->tryLogin(ui.m_userEdit->text(), ui.m_passwordEdit->text());
     } else {
         loginFinished(false);
     }
@@ -385,7 +394,6 @@ BugzillaInformationPage::BugzillaInformationPage(ReportAssistantDialog * parent)
     ui.m_compiledSourcesCheckBox->setChecked(
                                     DrKonqi::systemInformation()->compiledSources());
 
-    //ui.m_distributionGroupBox->setVisible(false);  //TODO do this?
 }
 
 void BugzillaInformationPage::aboutToShow()
@@ -396,6 +404,10 @@ void BugzillaInformationPage::aboutToShow()
             m_distroComboVisible = true;
             ui.m_distroChooserCombo->addItem(i18nc("@label:listbox KDE distribution method",
                                                    "Unspecified"),"unspecified");
+            ui.m_distroChooserCombo->addItem(i18nc("@label:listbox KDE distribution method",
+                                                   "Archlinux"), "Archlinux Packages");
+            ui.m_distroChooserCombo->addItem(i18nc("@label:listbox KDE distribution method",
+                                                   "Chakra"), "Chakra");
             ui.m_distroChooserCombo->addItem(i18nc("@label:listbox KDE distribution method",
                                                    "Debian stable"), "Debian stable");
             ui.m_distroChooserCombo->addItem(i18nc("@label:listbox KDE distribution method",
@@ -405,28 +417,24 @@ void BugzillaInformationPage::aboutToShow()
             ui.m_distroChooserCombo->addItem(i18nc("@label:listbox KDE distribution method",
                                                    "Exherbo"), "Exherbo Packages");
             ui.m_distroChooserCombo->addItem(i18nc("@label:listbox KDE distribution method",
-                                                   "Gentoo"), "Gentoo Packages");
+                                                   "Fedora"), "Fedora RPMs");
             ui.m_distroChooserCombo->addItem(i18nc("@label:listbox KDE distribution method",
-                                                   "Mandriva"), "Mandriva RPMs");
+                                                   "Gentoo"), "Gentoo Packages");
             ui.m_distroChooserCombo->addItem(i18nc("@label:listbox KDE distribution method",
                                                    "Mageia"), "Mageia RPMs");
             ui.m_distroChooserCombo->addItem(i18nc("@label:listbox KDE distribution method",
-                                                   "Slackware"), "Slackware Packages");
+                                                   "Mandriva"), "Mandriva RPMs");
             ui.m_distroChooserCombo->addItem(i18nc("@label:listbox KDE distribution method",
-                                                   "SuSE/OpenSUSE"), "openSUSE RPMs");
-            ui.m_distroChooserCombo->addItem(i18nc("@label:listbox KDE distribution method",
-                                                   "RedHat"), "RedHat RPMs");
-            ui.m_distroChooserCombo->addItem(i18nc("@label:listbox KDE distribution method",
-                                                   "Fedora"), "Fedora RPMs");
-            ui.m_distroChooserCombo->addItem(i18nc("@label:listbox KDE distribution method",
-                                                   "Kubuntu/Ubuntu (and derivatives)"),
-                                                   "Ubuntu Packages");
+                                                   "OpenSUSE"), "openSUSE RPMs");
             ui.m_distroChooserCombo->addItem(i18nc("@label:listbox KDE distribution method",
                                                    "Pardus"), "Pardus Packages");
             ui.m_distroChooserCombo->addItem(i18nc("@label:listbox KDE distribution method",
-                                                   "Chakra"), "Chakra");
+                                                   "RedHat"), "RedHat RPMs");
             ui.m_distroChooserCombo->addItem(i18nc("@label:listbox KDE distribution method",
-                                                   "Archlinux"), "Archlinux Packages");
+                                                   "Slackware"), "Slackware Packages");
+            ui.m_distroChooserCombo->addItem(i18nc("@label:listbox KDE distribution method",
+                                                   "Ubuntu (and derivatives)"),
+                                                   "Ubuntu Packages");
             ui.m_distroChooserCombo->addItem(i18nc("@label:listbox KDE distribution method",
                                                    "FreeBSD (Ports)"), "FreeBSD Ports");
             ui.m_distroChooserCombo->addItem(i18nc("@label:listbox KDE distribution method",
@@ -647,7 +655,7 @@ BugzillaPreviewPage::BugzillaPreviewPage(ReportAssistantDialog * parent)
 
 void BugzillaPreviewPage::aboutToShow()
 {
-    ui.m_previewEdit->setText(reportInterface()->generateReport(true));
+    ui.m_previewEdit->setText(reportInterface()->generateReportFullText(true));
 }
 
 //END BugzillaPreviewPage
@@ -744,7 +752,7 @@ void BugzillaSendPage::openReportContents()
 {
     if (!m_contentsDialog)
     {
-        QString report = reportInterface()->generateReport(false) + QLatin1Char('\n') +
+        QString report = reportInterface()->generateReportFullText(false) + QLatin1Char('\n') +
                             i18nc("@info/plain report to KDE bugtracker address","Report to %1",
                                   DrKonqi::crashedApplication()->bugReportAddress());
         m_contentsDialog = new ReportInformationDialog(report);
@@ -806,7 +814,7 @@ UnhandledErrorDialog::UnhandledErrorDialog(QWidget * parent, const QString & err
     htmlView->setHtml(extendedMessage);
 
     setMinimumSize(QSize(550, 350));
-    resize(QSize(550, 350));
+    resize(minimumSize());
 
     show();
 }
