@@ -23,7 +23,6 @@
 #include "reportassistantpage.h"
 
 #include "reportassistantpages_base.h"
-#include "bugzillalib.h"
 
 #include "ui_assistantpage_bugzilla_login.h"
 #include "ui_assistantpage_bugzilla_information.h"
@@ -33,7 +32,7 @@
 namespace KWallet { class Wallet; }
 class KCapacityBar;
 
-/** Bugs.kde.org login **/
+/** Bugzilla login **/
 class BugzillaLoginPage: public ReportAssistantPage
 {
     Q_OBJECT
@@ -52,11 +51,13 @@ private Q_SLOTS:
 
     void walletLogin();
 
+    void updateLoginButtonStatus();
+
 Q_SIGNALS:
     void loggedTurnToNextPage();
 
 private:
-    bool kWalletEntryExists();
+    bool kWalletEntryExists(const QString&);
     void openWallet();
     bool canSetCookies();
 
