@@ -409,8 +409,20 @@ int main(int argc, char **argv)
                     delete installer;
                     return 1;
                 }
-            } else {
+            // Need to check for theme package type, and uninstall anyway, since they aren't returned
+            // in the list of plugins. Fixes https://bugs.kde.org/show_bug.cgi?id=149479
+            } else if (type.compare(i18nc("package type", "theme"), Qt::CaseInsensitive) == 0 ||
+                       type.compare("theme", Qt::CaseInsensitive) == 0) {
+                if (installer->uninstallPackage(pluginName, packageRoot)) {
+                    output(i18n("Successfully removed %1", pluginName));
+                } else if (!args->isSet("upgrade")) {
+                    output(i18n("Removal of %1 failed.", pluginName));
+                    delete installer;
+                    return 1;
+                }
+            }else {
                 output(i18n("Plugin %1 is not installed.", pluginName));
+                return 1;
             }
         }
         if (args->isSet("install") || args->isSet("upgrade")) {
